@@ -179,7 +179,7 @@ pub fn cmd_stats(gc: Conf, sc: ConfStats) -> Result<bool, Error> {
     let hist = get_hist(&gc.logfile, gc.from, gc.to, sc.show, &sc.search, sc.exact)?;
     let moves = PkgMoves::new(&Mtimedb::new());
     let h = [sc.group.name(), "Logged emerges", "Install/Update", "Unmerge/Clean", "Sync"];
-    let mut tblc = Table::new(&gc).margin(1, " ").header(h);
+    let mut tblc = Table::new(&gc).align_left(0).margin(1, " ").header(h);
     let h = [sc.group.name(), "Repo", "Syncs", "Total time", "Predict time"];
     let mut tbls = Table::new(&gc).align_left(0).align_left(1).margin(1, " ").header(h);
     let h = [sc.group.name(),
@@ -499,11 +499,18 @@ pub fn cmd_predict(gc: Conf, mut sc: ConfPred) -> Result<bool, Error> {
 
     // Gather and print per-package and indivudual stats.
     let mut totcount = 0;
+    let mut totbuild = 0;
+    let mut totbin = 0;
     let mut totunknown = 0;
     let mut totpredict = 0;
     let mut totelapsed = 0;
     for p in pkgs {
         totcount += 1;
+        if p.bin {
+            totbin += 1;
+        } else {
+            totbuild += 1;
+        }
         // Find the elapsed time, if currently running
         let elapsed = match started.remove(p.ebuild_version()) {
             Some((s, _)) if einfo.pkgs.contains(&p) => now - s,
@@ -545,56 +552,72 @@ pub fn cmd_predict(gc: Conf, mut sc: ConfPred) -> Result<bool, Error> {
         tbl.skiprow(&[&gc.skip, &"(skip last ", &lastskip, &")"]);
     }
     // Print summary line
-    if totcount > 0 {
-        if sc.show.tot {
-            let mut s: Vec<&dyn Disp> = vec![&"Estimate for ",
-                                             &gc.cnt,
-                                             &totcount,
-                                             &gc.clr,
-                                             if totcount > 1 { &" ebuilds" } else { &" ebuild" }];
-            if totunknown > 0 {
-                s.extend::<[&dyn Disp; 5]>([&", ", &gc.cnt, &totunknown, &gc.clr, &" unknown"]);
-            }
-            let e = FmtDur(totelapsed);
-            if totelapsed > 0 {
-                s.extend::<[&dyn Disp; 4]>([&", ", &e, &gc.clr, &" elapsed"]);
-            }
-            tbl.row([&s,
-                     &[&FmtDur(totpredict), &gc.clr],
-                     &[&"@ ", &gc.dur, &FmtDate(now + totpredict)]]);
-        }
-    } else {
+    if totcount == 0 {
         tbl.row([&[&"No pretended merge found"], &[], &[]]);
+    } else if sc.show.tot {
+        let mut s: Vec<&dyn Disp> = vec![&"Estimate for "];
+        if totbuild > 0 {
+            s.extend([&gc.cnt as &dyn Disp,
+                      &totbuild,
+                      &gc.clr,
+                      if totbuild > 1 { &" builds" } else { &" build" }]);
+        }
+        if totbin > 0 {
+            s.extend([if totbuild > 0 { &", " } else { &"" } as &dyn Disp,
+                      &gc.cnt,
+                      &totbin,
+                      &gc.clr,
+                      if totbin > 1 { &" binaries" } else { &" binary" }]);
+        }
+        if totunknown > 0 {
+            s.extend([&", " as &dyn Disp, &gc.cnt, &totunknown, &gc.clr, &" unknown"]);
+        }
+        let e = FmtDur(totelapsed);
+        if totelapsed > 0 {
+            s.extend([&", " as &dyn Disp, &e, &gc.clr, &" elapsed"]);
+        }
+        tbl.row([&s,
+                 &[&FmtDur(totpredict), &gc.clr],
+                 &[&"@ ", &gc.dur, &FmtDate(now + totpredict)]]);
     }
     Ok(totcount > 0)
 }
 
 pub fn cmd_accuracy(gc: Conf, sc: ConfAccuracy) -> Result<bool, Error> {
     let hist = get_hist(&gc.logfile, gc.from, gc.to, Show::m(), &sc.search, sc.exact)?;
-    let mut pkg_starts: HashMap<String, i64> = HashMap::new();
-    let mut pkg_times: BTreeMap<String, Times> = BTreeMap::new();
-    let mut pkg_errs: BTreeMap<String, Vec<f64>> = BTreeMap::new();
+    let mut pkg_starts: HashMap<String, (i64, bool)> = HashMap::new();
+    let mut pkg_times: BTreeMap<(String, bool), Times> = BTreeMap::new();
+    let mut pkg_errs: BTreeMap<(String, bool), Vec<f64>> = BTreeMap::new();
     let mut found = false;
-    let h = ["Date", "Package", "Real", "Predicted", "Error"];
+    let h = ["Date", "Package", "Real", sc.avg.as_str(), "Samples", "Error"];
     let mut tbl = Table::new(&gc).align_left(0).align_left(1).last(sc.last).header(h);
     for p in hist {
         match p {
             Hist::MergeStart { ts, key, .. } => {
                 // This'll overwrite any previous entry, if a merge started but never finished
-                pkg_starts.insert(key, ts);
+                pkg_starts.insert(key, (ts, false));
+            },
+            Hist::MergeBin { key, .. } => {
+                if let Some((_, bin)) = pkg_starts.get_mut(&key) {
+                    *bin = true;
+                }
             },
             Hist::MergeStop { ts, ref key, .. } => {
                 found = true;
-                if let Some(start) = pkg_starts.remove(key) {
-                    let times = pkg_times.entry(p.ebuild().to_owned()).or_insert(Times::new());
+                if let Some((start, bin)) = pkg_starts.remove(key) {
+                    let times =
+                        pkg_times.entry((p.ebuild().to_owned(), bin)).or_insert(Times::new());
                     let real = ts - start;
+                    let samples = times.count.min(sc.lim.into());
                     match times.pred(sc.lim, sc.avg) {
                         -1 => {
                             if sc.show.merge {
                                 tbl.row([&[&FmtDate(ts)],
-                                         &[&gc.merge, &p.ebuild_version()],
+                                         &[if bin { &gc.binmerge } else { &gc.merge },
+                                           &p.ebuild_version()],
                                          &[&FmtDur(real)],
                                          &[],
+                                         &[],
                                          &[]])
                             }
                         },
@@ -602,12 +625,14 @@ pub fn cmd_accuracy(gc: Conf, sc: ConfAccuracy) -> Result<bool, Error> {
                             let err = (pred - real).abs() as f64 * 100.0 / real as f64;
                             if sc.show.merge {
                                 tbl.row([&[&FmtDate(ts)],
-                                         &[&gc.merge, &p.ebuild_version()],
+                                         &[if bin { &gc.binmerge } else { &gc.merge },
+                                           &p.ebuild_version()],
                                          &[&FmtDur(real)],
                                          &[&FmtDur(pred)],
-                                         &[&gc.cnt, &format!("{err:.1}%")]])
+                                         &[&gc.cnt, &samples],
+                                         &[&format!("{err:.1}%")]])
                             }
-                            let errs = pkg_errs.entry(p.ebuild().to_owned()).or_default();
+                            let errs = pkg_errs.entry((p.ebuild().to_owned(), bin)).or_default();
                             errs.push(err);
                         },
                     }
@@ -620,9 +645,10 @@ pub fn cmd_accuracy(gc: Conf, sc: ConfAccuracy) -> Result<bool, Error> {
     drop(tbl);
     if sc.show.tot {
         let mut tbl = Table::new(&gc).align_left(0).header(["Package", "Error"]);
-        for (p, e) in pkg_errs {
+        for ((p, b), e) in pkg_errs {
             let avg = e.iter().sum::<f64>() / e.len() as f64;
-            tbl.row([&[&gc.pkg, &p], &[&gc.cnt, &format!("{avg:.1}%")]]);
+            tbl.row([&[if b { &gc.binpkg } else { &gc.pkg }, &p],
+                     &[&gc.cnt, &format!("{avg:.1}%")]]);
         }
     }
     Ok(found)
