@@ -9,8 +9,7 @@ pub fn build_cli() -> Command {
     let pkg = Arg::new("search").num_args(..)
                                 .display_order(1)
                                 .help_heading("Filter")
-                                // Workaround bad alignment, might be fixed in clap 4
-                                .help("    Show only packages/repos matching <search>")
+                                .help("Show only packages/repos matching <search>")
                                 .long_help("Show only packages/repos matching <search>\n\
                                             Multiple terms can be provided\n\
                                             Matches using a regex unless `--exact` is specified\n\
@@ -292,8 +291,8 @@ pub fn build_cli() -> Command {
                                    .global(true)
                                    .display_order(29)
                                    .help_heading("Format")
-                                   .help("Ouput format (columns/tab/auto)")
-                                   .long_help("Ouput format (columns/tab/auto)\n  \
+                                   .help("Output format (columns/tab/auto)")
+                                   .long_help("Output format (columns/tab/auto)\n  \
                                                (default)|auto|a: columns on tty, tab otherwise\n  \
                                                columns|c:        space-aligned columns\n  \
                                                tab|t:            tab-separated values");
