@@ -7,8 +7,8 @@ use regex::Regex;
 use std::{io::Write as _,
           str::FromStr,
           time::{SystemTime, UNIX_EPOCH}};
-use time::{macros::format_description, parsing::Parsed, Date, Duration, Month, OffsetDateTime,
-           UtcOffset, Weekday};
+use time::{format_description::FormatItem, macros::format_description, parsing::Parsed, Date,
+           Duration, Month, OffsetDateTime, UtcOffset, Weekday};
 
 /// Get the UtcOffset to parse/display datetimes with.
 /// Needs to be called before starting extra threads.
@@ -26,7 +26,7 @@ pub fn get_offset(utc: bool) -> UtcOffset {
 // It'd be nice to support user-defined formats, but lifetimes make this a bit akward.
 // See <https://github.com/time-rs/time/issues/429>
 #[derive(Clone, Copy)]
-pub struct DateStyle(&'static [time::format_description::FormatItem<'static>]);
+pub struct DateStyle(&'static [FormatItem<'static>]);
 impl Default for DateStyle {
     fn default() -> Self {
         Self(format_description!("[year]-[month]-[day] [hour]:[minute]:[second]"))
@@ -101,7 +101,7 @@ impl ArgParse<String, UtcOffset> for TimeBound {
             Ok(i) => return Ok(Self::Run(i)),
             Err(ea) => ea,
         };
-        match parse_date_ago(s) {
+        match parse_date_ago(s, OffsetDateTime::now_utc()) {
             Ok(i) => Ok(Self::Unix(i)),
             Err(er) => {
                 let m = format!("Not a unix timestamp ({et}), absolute date ({ea}), relative date ({er}), or command ({ec})");
@@ -123,10 +123,9 @@ fn parse_command_num(s: &str) -> Result<usize, Error> {
 }
 
 /// Parse a number of day/years/hours/etc in the past, relative to current time
-fn parse_date_ago(s: &str) -> Result<i64, Error> {
+fn parse_date_ago(s: &str, mut now: OffsetDateTime) -> Result<i64, Error> {
     ensure!(s.chars().all(|c| c.is_ascii_alphanumeric() || c == ' ' || c == ','), "bad char");
     ensure!(s.chars().any(|c| c.is_ascii_alphabetic()), "empty");
-    let mut now = OffsetDateTime::now_utc();
 
     // Handle case where only a span is given
     if let Ok(now) = parse_date_span(1, s.trim(), now) {
@@ -147,7 +146,9 @@ fn parse_date_ago(s: &str) -> Result<i64, Error> {
 fn parse_date_span(num: i32, span: &str, now: OffsetDateTime) -> Result<OffsetDateTime, Error> {
     Ok(match span {
         "y" | "year" | "years" => {
-            let d = Date::from_calendar_date(now.year() - num, now.month(), now.day())?;
+            let year = now.year() - num;
+            let month = now.month();
+            let d = Date::from_calendar_date(year, month, now.day().min(month.length(year)))?;
             now.replace_date(d)
         },
         "m" | "month" | "months" => {
@@ -159,7 +160,7 @@ fn parse_date_span(num: i32, span: &str, now: OffsetDateTime) -> Result<OffsetDa
                     year -= 1;
                 }
             }
-            let d = Date::from_calendar_date(year, month, now.day())?;
+            let d = Date::from_calendar_date(year, month, now.day().min(month.length(year)))?;
             now.replace_date(d)
         },
         "w" | "week" | "weeks" => now - num * Duration::WEEK,
@@ -173,7 +174,6 @@ fn parse_date_span(num: i32, span: &str, now: OffsetDateTime) -> Result<OffsetDa
 
 /// Parse rfc3339-like format with added flexibility
 fn parse_date_yyyymmdd(s: &str, offset: UtcOffset) -> Result<i64, Error> {
-    use time::format_description::{modifier::*, Component, FormatItem::*};
     let mut p = Parsed::new().with_hour_24(0)
                              .unwrap()
                              .with_minute(0)
@@ -186,30 +186,14 @@ fn parse_date_yyyymmdd(s: &str, offset: UtcOffset) -> Result<i64, Error> {
                              .unwrap()
                              .with_offset_second_signed(offset.seconds_past_minute())
                              .unwrap();
-    // See <https://github.com/time-rs/time/issues/428>
-    let rest = p.parse_items(s.as_bytes(), &[
-        Component(Component::Year(Year::default())),
-        Literal(b"-"),
-        Component(Component::Month(Month::default())),
-        Literal(b"-"),
-        Component(Component::Day(Day::default())),
-        Optional(&Compound(&[
-            First(&[
-                Literal(b"T"),
-                Literal(b" ")
-            ]),
-            Component(Component::Hour(Hour::default())),
-            Literal(b":"),
-            Component(Component::Minute(Minute::default())),
-            Optional(&Compound(&[
-                Literal(b":"),
-                Component(Component::Second(Second::default()))
-            ]))
-        ]))
-    ])?;
-    if !rest.is_empty() {
-        bail!("junk at end")
-    }
+    const FMT: &[FormatItem<'_>] = format_description!(
+                                                       version = 2,
+                                                       "[year]-[month]-[day]\
+        [optional [[first [T][ ]][hour]:[minute][optional [:[second]]]]]\
+        [optional [[first [Z][[offset_hour]:[offset_minute]]]]]"
+    );
+    let rest = p.parse_items(s.as_bytes(), FMT)?;
+    ensure!(rest.is_empty(), "junk at end");
     Ok(OffsetDateTime::try_from(p)?.unix_timestamp())
 }
 
@@ -332,56 +316,62 @@ mod test {
     use super::*;
     use time::format_description::well_known::Rfc3339;
 
-    fn parse_3339(s: &str) -> OffsetDateTime {
+    fn parse_rfc(s: &str) -> OffsetDateTime {
         OffsetDateTime::parse(s, &Rfc3339).expect(s)
     }
-    fn parse_date(s: &str, o: UtcOffset) -> Result<TimeBound, ArgError> {
+    fn parse_fromto(s: &str, o: UtcOffset) -> Result<TimeBound, ArgError> {
         TimeBound::parse(&String::from(s), o, "")
     }
+    fn parse_ago(ago: &str, now: &str) -> String {
+        parse_date_ago(ago, parse_rfc(now)).map(fmt_utctime).unwrap()
+    }
     fn ts(t: OffsetDateTime) -> i64 {
         t.unix_timestamp()
     }
 
     #[test]
     fn date() {
-        let then =
-            OffsetDateTime::parse("2018-04-03T00:00:00Z", &Rfc3339).unwrap().unix_timestamp();
-        let now = epoch_now();
-        let (day, hour, min) = (60 * 60 * 24, 60 * 60, 60);
-        let tz_utc = UtcOffset::UTC;
+        let tb_unix = |rfc| TimeBound::Unix(ts(parse_rfc(rfc)));
+        let utc = UtcOffset::UTC;
 
         // Absolute dates
-        assert_eq!(Ok(TimeBound::Unix(then)), parse_date(" 1522713600 ", tz_utc));
-        assert_eq!(Ok(TimeBound::Unix(then)), parse_date(" 2018-04-03 ", tz_utc));
-        assert_eq!(Ok(TimeBound::Unix(then + hour + min)), parse_date("2018-04-03 01:01", tz_utc));
-        assert_eq!(Ok(TimeBound::Unix(then + hour + min + 1)),
-                   parse_date("2018-04-03 01:01:01", tz_utc));
-        assert_eq!(Ok(TimeBound::Unix(then + hour + min + 1)),
-                   parse_date("2018-04-03T01:01:01", tz_utc));
+        assert_eq!(Ok(tb_unix("2018-04-03T00:00:00Z")), parse_fromto(" 1522713600 ", utc));
+        assert_eq!(Ok(tb_unix("2018-04-03T00:00:00Z")), parse_fromto(" 2018-04-03 ", utc));
+        assert_eq!(Ok(tb_unix("2018-04-03T01:02:00Z")), parse_fromto("2018-04-03 01:02", utc));
+        assert_eq!(Ok(tb_unix("2018-04-03T01:02:03Z")), parse_fromto("2018-04-03 01:02:03", utc));
+        assert_eq!(Ok(tb_unix("2018-04-03T01:02:03Z")), parse_fromto("2018-04-03T01:02:03", utc));
+        assert_eq!(Ok(tb_unix("2018-04-03T01:02:03Z")), parse_fromto("2018-04-03T01:02:03Z", utc));
+        assert_eq!(Ok(tb_unix("2018-04-03T00:02:03Z")),
+                   parse_fromto("2018-04-03T01:02:03+01:00", utc));
 
         // Different timezone (not calling `get_utcoffset()` because tests are threaded, which makes
         // `UtcOffset::current_local_offset()` error out)
-        for secs in [hour, -1 * hour, 90 * min, -90 * min] {
-            let offset = dbg!(UtcOffset::from_whole_seconds(secs.try_into().unwrap()).unwrap());
-            assert_eq!(Ok(TimeBound::Unix(then - secs)), parse_date("2018-04-03T00:00", offset));
+        for secs in [3600, -7200, 5400, -5400, 42, -42] {
+            let offset = UtcOffset::from_whole_seconds(secs.try_into().unwrap()).unwrap();
+            let tb = TimeBound::Unix(ts(parse_rfc("2018-04-03T00:00:00Z")) - secs);
+            assert_eq!(Ok(tb), parse_fromto("2018-04-03T00:00", offset));
         }
 
         // Relative dates
-        assert_eq!(Ok(TimeBound::Unix(now - hour - 3 * day - 45)),
-                   parse_date("1 hour, 3 days  45sec", tz_utc));
-        assert_eq!(Ok(TimeBound::Unix(now - 5 * 7 * day)), parse_date("5 weeks", tz_utc));
-        assert_eq!(Ok(TimeBound::Unix(now - hour - 2 * day)), parse_date("2d1h", tz_utc));
-        assert_eq!(Ok(TimeBound::Unix(now - 7 * day)), parse_date("w", tz_utc));
+        assert_eq!("2025-05-03T11:57:56Z",
+                   parse_ago("1 hour, 3 days  45sec", "2025-05-06T12:58:41Z"));
+        assert_eq!("2025-04-01T12:58:41Z", parse_ago("5 weeks", "2025-05-06T12:58:41Z"));
+        assert_eq!("2025-05-04T11:58:41Z", parse_ago("2d1h", "2025-05-06T12:58:41Z"));
+        assert_eq!("2025-04-29T12:58:41Z", parse_ago("w", "2025-05-06T12:58:41Z"));
+        assert_eq!("2025-02-28T01:02:03Z", parse_ago("2m", "2025-04-29T01:02:03Z"));
+        assert_eq!("2024-02-29T01:02:03Z", parse_ago("2m", "2024-04-29T01:02:03Z"));
+        assert_eq!("2023-02-28T01:02:03Z", parse_ago("y", "2024-02-29T01:02:03Z"));
 
         // Failure cases
-        assert!(parse_date("", tz_utc).is_err());
-        assert!(parse_date(" ", tz_utc).is_err());
-        assert!(parse_date(",", tz_utc).is_err());
-        assert!(parse_date("junk2018-04-03T01:01:01", tz_utc).is_err());
-        assert!(parse_date("2018-04-03T01:01:01junk", tz_utc).is_err());
-        assert!(parse_date("152271000o", tz_utc).is_err());
-        assert!(parse_date("1 day 3 centuries", tz_utc).is_err());
-        assert!(parse_date("a while ago", tz_utc).is_err());
+        assert!(parse_fromto("", utc).is_err());
+        assert!(parse_fromto(" ", utc).is_err());
+        assert!(parse_fromto(",", utc).is_err());
+        assert!(parse_fromto("junk2018-04-03T01:01:01", utc).is_err());
+        assert!(parse_fromto("2018-04-03T01:01:01junk", utc).is_err());
+        assert!(parse_fromto("2018-02-29T01:01:01", utc).is_err());
+        assert!(parse_fromto("152271000o", utc).is_err());
+        assert!(parse_fromto("1 day 3 centuries", utc).is_err());
+        assert!(parse_fromto("a while ago", utc).is_err());
     }
 
     #[test]
@@ -412,13 +402,13 @@ mod test {
             // returned by the function is offset.
             let v: Vec<&str> = t.split_whitespace().collect();
             let (base_s, year_s, month_s, week_s, day_s) = (v[0], v[1], v[2], v[3], v[4]);
-            let base_utc = parse_3339(&format!("{base_s}+00:00"));
+            let base_utc = parse_rfc(&format!("{base_s}+00:00"));
             for offset_s in ["+00:00", "+05:00", "-10:30"] {
-                let base = parse_3339(&format!("{base_s}{offset_s}"));
-                let year = parse_3339(&format!("{year_s}T00:00:00{offset_s}"));
-                let month = parse_3339(&format!("{month_s}T00:00:00{offset_s}"));
-                let week = parse_3339(&format!("{week_s}T00:00:00{offset_s}"));
-                let day = parse_3339(&format!("{day_s}T00:00:00{offset_s}"));
+                let base = parse_rfc(&format!("{base_s}{offset_s}"));
+                let year = parse_rfc(&format!("{year_s}T00:00:00{offset_s}"));
+                let month = parse_rfc(&format!("{month_s}T00:00:00{offset_s}"));
+                let week = parse_rfc(&format!("{week_s}T00:00:00{offset_s}"));
+                let day = parse_rfc(&format!("{day_s}T00:00:00{offset_s}"));
                 // Check our test data is correct
                 let offset = base.offset();
                 assert!(base < year && base < month && base < week && base < day,
